%----------------------------------------------
% Read in image files from list and normalize
% Create Integral Image versions of images
%   These take a short time and is independent of 
%   the number of and type of features
%----------------------------------------------

%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 1. Read in files from list
%%%%%%%%%%%%%%%%%%%%%%%%%%%%
FaceData=[];
global cropsize
fpath=which(mfilename);pathMF = fpath(1:findstr(upper(mfilename),upper(fpath))-1);
%[fname,pname] = uigetfile([fpath 'list_img.txt'] ,'Select text file with image names');
[fname,pname] = uigetfile([pathMF 'list_img.txt'] ,'Select text file with image names');

FID = fopen([pname,fname]);
%FID = fopen("list_img.txt");
line_string = fgetl(FID)
if ~strcmp(line_string,'FACES') % 1st line has this?
    disp('Corrupt ''list_img.txt'' file!');
    return;
end

while (~feof(FID))
    line_string=fgetl(FID);
    if (line_string == -1)
        break; %-1 if eof
    else
        if strcmp(line_string,'NONFACES');  % watch for nonfaces
            break;
        end
        Imr=imread(line_string);
        %imshow(Imr);
        Imr=Imr(:)';
        FaceData=[FaceData ; Imr]; %each row is a face
    end
end
FaceData=double(FaceData); %Max=255 Min=0
sprintf('#faces %d',size(FaceData,1))
%read in Non faces
NonFaceData=[];
while (~feof(FID))
    line_string=fgetl(FID);
    if (line_string == -1)
        break; %-1 if eof
    else
        Imr=imread(line_string);
        Imr=Imr(:)';
        NonFaceData=[NonFaceData ; Imr]; %each row is a non-face
    end
end
NonFaceData=double(NonFaceData); %Max=255 Min=0
sprintf('#nonfaces %d',size(NonFaceData,1))
%%%%%%%%%%%%%%%% NORMALIZE THE IMAGES %%%%%%%%%%%%%%%%
for i=1:size(FaceData,1)
%     faceraw=reshape(FaceData(i,:),cropsize,cropsize);
%     NonFaceraw=reshape(NonFaceData(i,:),cropsize,cropsize);
%     faceraw=normImageF(faceraw);                     % use this instead?
%     NonFaceraw=normImageF(NonFaceraw);               % use this instead?  
%     faceraw=reshape(faceraw,1,cropsize*cropsize);
%     NonFaceraw=reshape(NonFaceraw,1,cropsize*cropsize);
%     FaceData(i,:)=faceraw;
%     NonFaceData(i,:)=NonFaceraw;
    if max(FaceData(i,:)) ~= min(FaceData(i,:))
        FaceData(i,:)=(FaceData(i,:)-min(FaceData(i,:)))/(max(FaceData(i,:))-min(FaceData(i,:)));
    end
    if max(NonFaceData(i,:)) ~= min(NonFaceData(i,:))
        NonFaceData(i,:)=(NonFaceData(i,:)-min(NonFaceData(i,:)))/(max(NonFaceData(i,:))-min(NonFaceData(i,:)));
    end
end
save([pathMF 'FaceNonFaceData.mat'],'FaceData','NonFaceData');% Normalized and ready

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 2. Create Integral Image equivalents of file
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
patchsize=cropsize*cropsize;
patchsizepad=(cropsize+1)*(cropsize+1);
numFaces = size(FaceData,1);        % get number of faces
numNonFaces = size(NonFaceData,1);  % & nonfaces

faces= zeros(numFaces,patchsize);
nonfaces= zeros(numNonFaces,patchsize);
%facesPad= zeros(numFaces,patchsizepad);
cumFaces= zeros(numFaces,patchsizepad);
%nonfacesPad= zeros(numFaces,patchsizepad);
cumNonFace= zeros(numFaces,patchsizepad); 

for ind= 1:numFaces
    face= FaceData(ind,:);  % keep original
    padFace= padJN(face);
    faces(ind,:)= face;
    %facesPad(ind,:)= padFace;
    cumFaces(ind,:)= cumImageJN(padFace);   % <--- write this function!
end
clear FaceData;
for ind= 1:numNonFaces
    NonFace= NonFaceData(ind,:);
    NonFacePad= padJN(NonFace);
    nonfaces(ind,:)= NonFace;
    %nonfacesPad(ind,:)= NonFacePad;
    cumNonFaces(ind,:)= cumImageJN(NonFacePad);    % <--- write this function!
end 
clear NonFaceData;
% xN is total number of faces and of non-faces.
xN=numNonFaces+numFaces;
save([pathMF 'images.mat'], 'faces', 'cumFaces', 'nonfaces', 'cumNonFaces');
fclose(FID);
clear faces cumFaces nonfaces cumNonFaces 
%imshow(reshape(NoiseData(1,:),24,24))
