function [threshold, parity, wtdError]= findThreshold(featval, posFeatureWeights, negFeatureWeights)
% [threshold, parity, wtdError]= findThreshold(featval, posFeatureWeights, negFeatureWeights)
% 
% Finds the optimal 'threshold' (scalar), 'parity' (-1 or 1) and weighted error 'wtdError' of a
% given feature-response matrix 'featval' ((Mpos+Mneg)x1) on the trainingdata. The
% distribution over the trainingdata should also be supplied, with
% posFeatureWeights (1xMpos) for weights of positive samples and
% negFeatureWeights (1xMneg) for weights of negative samples.
%


nPos = length(posFeatureWeights);
nNeg = length(negFeatureWeights);
nTot = length(featval);
if nTot ~= nPos + nNeg
    error('invalid input to findThreshold!');
end
minH = min(featval);
maxH = max(featval);
nHist = 100;
dHist = (maxH - minH)/nHist; 
hist = zeros(1,nHist);
histPos = hist;
histNeg = hist;
for i = 1:nPos
    j = floor((featval(i) - minH)/dHist) + 1;
    if j > nHist; j = nHist; end
    histPos(j) = histPos(j) + posFeatureWeights(i);
end
for i = 1:nNeg
    j = floor((featval(nPos + i) - minH)/dHist) + 1;
    if j > nHist; j = nHist; end
    histNeg(j) = histNeg(j) + negFeatureWeights(i);
end

hist = histPos - histNeg;
Pdiff = cumsum(hist);
[Pmax PmaxIdx] = max(Pdiff);
[Pmin PminIdx] = min(Pdiff);
if Pmax > -Pmin
    parity = 1;
    thresholdIdx = PmaxIdx + 1;
else
    parity = -1;
    thresholdIdx = PminIdx + 1;
end

%============== complete this section =================
threshold = 
if parity == 1
    wtdError = ...
        
else
    wtdError = ...
        
end
%======================================================

%Plot: 
plotOn = 0;   %<----- set to 1 if you want to show histograms.
if (plotOn)
    hIdx = linspace(minH+dHist/2,maxH-dHist/2,nHist);
    %hold off;
    plot(hIdx, hist, ':k', hIdx, histPos, '-b', hIdx, histNeg, '-r', threshold, 0, '*g');
    %hold on;
    %plot(hIdx, Pdiff, ':m');
end
