function [V, Vidx, F, Fidx, Pidx]= violaboxzero(nI,nJ,nMin,nMax,nScale) 
%[V, Vidx, F, Fidx, Pidx]= violaboxzero(nI,nJ,nMin,nMax,nScale) 
%
% F(Pidx,R) gives the coefficients for every integral image element, for
% every possible rectangle index R=Fidx(PidxTL,PidxBR), where PidxTL is the
% top left (excluding) and PidxBR is the bottom right (including) pixels in
% a padded image. 
% Pidx(col,row) is the pixel index for any row and column for padded
% images.
% V(Pidx,c) gives the coefficients for every integral image element, for
% every viola feature c=Vidx(R,t), where t is the type of the viola feature
% and R is the index of the rectangle it is in. The sparse matrix V has
% only four non-zero elements per rectangle for every feature. To get the
% feature value, the non-zero elements are multiplied with the
% corresponding integral image elements in the scalar product. 
%
% nI nJ are actual size of window -- without zero padding 
% nMin, nMax are the minimum and maximum size of the boxes 

if nargin < 5 
    nScale = nI*nJ; 
end 
if nargin < 4 
    nMax = max(nI,nJ); 
end 
if nargin < 3 
    nMin = 1; 
end; 
c = violaboxcount(nI,nJ,nMin,nMax); 
[F Fidx Pidx] = simpleboxeszero(nI,nJ); 
disp('did violaboxes zero') 
nI=nI+1; 
nJ=nJ+1; 
nPix = nI*nJ; 
% allocate sparse matrix 
V = sparse([],[],[],nPix,c,c); 
nF=size(F,2); 
Vidx = sparse([],[],[],nF,5,c); 
c=0; %index viola features 
for t = 1:6 
    si=1; sj=1; 
    switch t 
    case 1, si=2; % split i 2 
    case 2, sj=2; % split j 2 
    case 3, si=3; % split i 3 
    case 4, sj=3; % split j 3 
    case 5, si=2; sj=2; % split ij 2 
    case 6, si=3; sj=3; % center 
    end 
    %nIs = (min(2+nMax,nI) - (2+si*ceil(nMin/si)-1))/si+1 
    %nJs = (min(2+nMax,nJ) - (2+sj*ceil(nMin/sj)-1))/sj+1 
    si0 = si*ceil(nMin/si); % 0th size in i for this feature 
    sj0 = sj*ceil(nMin/sj); % 0th size in j for this feature 
    for i=2:nI; for j=2:nJ; 
            nIend= min(i+nMax,nI); 
            nJend= min(j+nMax,nJ); 
            for i2=i+si0-1:si:nIend; for j2=j+sj0-1:sj:nJend; 
                    iw = i2-i+1; 
                    jw = j2-j+1; 
                    c=c+1; 
                    Vidx(Fidx(Pidx(i,j),Pidx(i2,j2)),t)=c; 
                    switch t 
                    case 1 %split i 2 
                        iw = iw/2; 
                        b1 = Fidx(Pidx(i, j),Pidx(i+iw-1,j2)); 
                        b2 = Fidx(Pidx(i+iw,j),Pidx(i2, j2)); 
                        v = F(:,b1) - F(:,b2); 
                    case 2 % split j 2 
                        
                        %Fill this part
                        
                    case 3 % split i 3 
                        
                        %Fill this part
                        
                    case 4 %split j 3 
                        
                        %Fill this part
                        
                    case 5 % split ij 2 
                        
                        %Fill this part
                        
                    case 6 % center 
                        
                        %Fill this part
                        
                    end
                    
                    nf = sum(v~=0); 
                    if(nf>0) 
                        V(:,c)=v; 
                    else 
                        error ('empty feature!'); 
                    end 
                end; 
            end; 
        end; 
    end; 
end; 
